SystemOrganization addCategory: #'HostMenus-Mac'!

Object subclass: #HostSystemMenus
	instanceVariableNames: 'hostSystemProxy'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'HostMenus-Mac'!

!HostSystemMenus commentStamp: 'JMM 10/15/2004 13:02' prior: 0!
This class uses a proxy and a plugin to support access to the host operating system's menu api. 
Most of the work is done in the proxy and the proxy calls  a host OS specific plugin, or  uses FFI or whatever is applicable to make host menus work. 

Most menubar commands take a host window index value. This maps to the host window index value that is used by the host window plugin. This supports windows that support host menu bars. The macintosh has a single menu bar and all uses of windowIndex are later ignored in the macintosh proxy code. 

When menu events are passed up from the VM by a VM that actually generates the events, they are processed in EventSensor>>processMenuEvent: which calls HostSystemMenus>>defaultMenuBarForWindowIndex: N. This returns the proxy that handles the interface to the menu bar for the window that has windowIndex N. It then invokes 	HostSystemMenuProxy>>getHandlerForMenu:item:  to get a block that will act on the invocation of menu N, menu Item M.  See HostSystemMenusMenuItem class>>fakeKeyboardEventBlockascii:unicode: 
for the default blocks definition which defaults to insert the command key keyboard stroke into the event queue. This then mimics command key usage which is being watched for by Morphic/Tweak widgets. 

Structure:
 hostSystemProxy	HostSystemMenusProxy -- points to the proxy class that interfaces to the plugin
 Default				HostSystemMenus -- points to the single instance of HostSystemMenus

The macintosh plugin attempts to validate incoming menu handles. But care still must be taken not to pass in a bogus handle because this will crash the VM. Finalization is used to ensure 'lost' menu proxies are dealt with. 

!

!HostSystemMenus class methodsFor: 'instance creation' stamp: 'JMM 10/12/2004 14:36'!
activeMenuProxyClass
	"Return the concreteHostMenuProxy subclass for the platform on which we are
currently running."

	HostSystemMenusProxy allSubclasses do: [:class |
		class isActiveHostMenuProxyClass ifTrue: [^ class]].

	"no responding subclass; use HostSystemMenusProxy"
	^ HostSystemMenusProxy
! !

!HostSystemMenus class methodsFor: 'instance creation' stamp: 'GabrielOmarCotelli 6/4/2009 20:15'!
clearDefault
	Default := nil! !

!HostSystemMenus class methodsFor: 'accessing' stamp: 'JMM 10/1/2004 12:51'!
default
	^Default ifNil: [Default := self new] ifNotNil: [Default]! !

!HostSystemMenus class methodsFor: 'instance creation' stamp: 'JMM 10/12/2004 14:27'!
defaultMenuBarForWindowIndex: aWindowIndex
	^self default defaultMenuBarForWindowIndex: aWindowIndex
! !

!HostSystemMenus class methodsFor: 'instance creation' stamp: 'GabrielOmarCotelli 6/4/2009 20:15'!
initialize
	"Add me to the system startup list"
	"self initialize"
	self clearDefault.
	Smalltalk 
		addToStartUpList: self
		after: SmalltalkImage! !

!HostSystemMenus class methodsFor: 'accessing' stamp: 'JMM 5/15/2006 21:36'!
invokeCmd: aCmd 
	| app |

	app := self default hostSystemProxy application.
	app ifNil: [^self].
	app perform: aCmd ! !

!HostSystemMenus class methodsFor: 'accessing' stamp: 'JMM 5/15/2006 21:36'!
invokeCmd: aCmd with: anEvent
	| app |

	app := self default hostSystemProxy application.
	app ifNil: [^self].
	app perform: aCmd with: anEvent! !

!HostSystemMenus class methodsFor: 'accessing' stamp: 'JMM 5/15/2006 21:30'!
menuBarControler
	^self default hostSystemProxy! !

!HostSystemMenus class methodsFor: 'instance creation' stamp: 'JMM 10/1/2004 15:15'!
new
	^self basicNew initialize! !

!HostSystemMenus class methodsFor: 'instance creation' stamp: 'JMM 10/12/2004 11:45'!
setDefaultMenuProxyClass
	self default hostSystemProxy: self activeMenuProxyClass new.
	! !

!HostSystemMenus class methodsFor: 'instance creation' stamp: 'HenrikSperreJohansen 6/28/2010 12:21'!
startUp: resuming
	resuming ifFalse: [^self].
	self clearDefault.
	[self setDefaultMenuProxyClass] ifError: [].! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:08'!
appendMenu: aMenuHandle menuItems: aCollection
	self hostSystemProxy appendMenu: aMenuHandle menuItems: aCollection
! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:09'!
checkMenuItem: aMenuHandle item: anInteger checked: aBoolean
	self hostSystemProxy checkMenuItem: aMenuHandle item: anInteger checked: aBoolean! !

!HostSystemMenus methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:36'!
clearMenuBar: aWindowIndex
	self hostSystemProxy clearMenuBar: aWindowIndex! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:09'!
countMenuItems: aMenuHandle
	^self hostSystemProxy countMenuItems: aMenuHandle! !

!HostSystemMenus methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:36'!
createMenuBar: aWindowIndex
	self hostSystemProxy createMenuBar: aWindowIndex! !

!HostSystemMenus methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 14:31'!
defaultMenuBarForWindowIndex: aWindowIndex
	^self hostSystemProxy defaultMenuBarForWindowIndex: aWindowIndex! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:11'!
deleteMenu: aMenuHandle
	self hostSystemProxy deleteMenu: aMenuHandle
! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:12'!
deleteMenuItem: aMenuHandle item: aNumber
	self hostSystemProxy deleteMenuItem: aMenuHandle item: aNumber! !

!HostSystemMenus methodsFor: 'finalization' stamp: 'JMM 10/1/2004 13:02'!
destroyEveryThing
	self hostSystemProxy destroyEveryThing! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:12'!
disableMenuItem: aMenuHandle item: aNumber
	self hostSystemProxy disableMenuItem: aMenuHandle item: aNumber! !

!HostSystemMenus methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:37'!
disposeMenuBar: aWindowIndex
	self hostSystemProxy disposeMenuBar: aWindowIndex! !

!HostSystemMenus methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:37'!
drawMenuBar: aWindowIndex
	self hostSystemProxy drawMenuBar: aWindowIndex! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:13'!
enableMenuItem: aMenuHandle item: aNumber
	self hostSystemProxy enableMenuItem: aMenuHandle item: aNumber! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:13'!
getItemCmd: aMenuHandle item: aNumber
	^self hostSystemProxy getItemCmd: aMenuHandle item: aNumber! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:13'!
getItemIcon: aMenuHandle item: aNumber
	^self hostSystemProxy getItemIcon: aMenuHandle item: aNumber! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:18'!
getItemMark: aMenuHandle item: aNumber
	^self hostSystemProxy getItemMark: aMenuHandle item: aNumber
! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:14'!
getItemStyle: aMenuHandle item: aNumber
	^self hostSystemProxy getItemStyle: aMenuHandle item: aNumber
! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:19'!
getMenuHandle: aMenuID
	^self hostSystemProxy getMenuHandle: aMenuID! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:19'!
getMenuID: aMenuHandle
	^self hostSystemProxy getMenuID: aMenuHandle! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:19'!
getMenuItemText: aMenuHandle item: aNumber
	^self hostSystemProxy getMenuItemText: aMenuHandle item: aNumber! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:19'!
getMenuTitle: aMenuHandle
	^self hostSystemProxy getMenuTitle: aMenuHandle! !

!HostSystemMenus methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:37'!
hideMenuBar: aWindowIndex
	self hostSystemProxy hideMenuBar: aWindowIndex! !

!HostSystemMenus methodsFor: 'accessing' stamp: 'JMM 10/12/2004 14:26'!
hostSystemProxy
	hostSystemProxy ifNil: [self class setDefaultMenuProxyClass].
	^hostSystemProxy! !

!HostSystemMenus methodsFor: 'accessing' stamp: 'JMM 10/1/2004 12:52'!
hostSystemProxy: anObject
	hostSystemProxy := anObject! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:19'!
insertMenu: aMenuHandle beforeID: anId
	self hostSystemProxy insertMenu: aMenuHandle beforeID: anId! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:15'!
insertMenuItem: menuHandleOop item: anItem afterItem: anInteger
	self hostSystemProxy insertMenuItem: menuHandleOop item: anItem afterItem: anInteger

! !

!HostSystemMenus methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:37'!
isMenuBarVisible: aWindowIndex
	^self hostSystemProxy isMenuBarVisible: aWindowIndex! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:20'!
isMenuItemEnabled: aMenuHandle item: aNumber
	^self hostSystemProxy isMenuItemEnabled: aMenuHandle item: aNumber! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:37'!
newMenu: xmenuID menuTitle: menuTitle
	^self hostSystemProxy newMenu: xmenuID menuTitle: menuTitle
	! !

!HostSystemMenus methodsFor: 'accessing' stamp: 'JMM 10/1/2004 13:07'!
setHandlerForMenu: aMenuID item: anItem handler: aHandler
	self hostSystemProxy setHandlerForMenu: aMenuID item: anItem handler: aHandler
! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:37'!
setItemCmd: menuHandleOop item: anInteger cmdChar: anIntegerCmdChar
	self hostSystemProxy setItemCmd: menuHandleOop item: anInteger cmdChar: anIntegerCmdChar

! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:37'!
setItemMark: menuHandleOop item: anInteger markChar: aMarkChar
	self hostSystemProxy  setItemMark: menuHandleOop item: anInteger markChar: aMarkChar

	
! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:38'!
setItemStyle: menuHandleOop item: anInteger style: aStyle
	self hostSystemProxy setItemStyle: menuHandleOop item: anInteger style: aStyle

! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:38'!
setMenuItemHierarchicalID: menuHandleOop item: anInteger hierID: aMenuID
	self hostSystemProxy setMenuItemHierarchicalID: menuHandleOop item: anInteger hierID: aMenuID
! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:17'!
setMenuItemModifiers: menuHandleOop item: anInteger inModifiers: aUInt8
	self hostSystemProxy setMenuItemModifiers: menuHandleOop item: anInteger inModifiers: aUInt8
! !

!HostSystemMenus methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:38'!
setMenuTitle: menuHandleOop  title: aMenuText
	self hostSystemProxy setMenuTitle: menuHandleOop  title: aMenuText

! !

!HostSystemMenus methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:37'!
showMenuBar: aWindowIndex
	self hostSystemProxy showMenuBar: aWindowIndex! !

!HostSystemMenus methodsFor: 'accessing' stamp: 'JMM 8/3/2006 17:26'!
toggleReaderMode: aBool! !

Object subclass: #HostSystemMenusMenuItem
	instanceVariableNames: 'icon mark style cmd disabled text handler shift'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HostMenus-Mac'!

!HostSystemMenusMenuItem commentStamp: 'JMM 10/22/2004 11:04' prior: 0!
Holds on to information about a menu item, this allows you to create and populate a menu item which is then handed to the HostSystemMenus classes to actually build the menu item. It does not refect the real-time state of the menu item since changes to the menu items via HostSystemMenus are not recorded. For example to understand the actual enabled/disabled state you must make an api call to host os to get the actual state, the same applies to all other attributes. After creation the only attribute used is the handler which points to the block to execute when a menu item is activated.

icon 		pointer to icon information
mark 		mark character (ascii value)
style 		pointer to style information
cmd 		command magic number
disabled 	true if disabled 
text 		text of the menu item
handler 	pointer to the block that gets executed when you invoke the menu item. 
!

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'JMM 10/18/2004 08:58'!
activeMenuItemClass
	"Return the HostSystemMenusMenuItem subclass for the platform on which we are
currently running."

	HostSystemMenusMenuItem allSubclasses do: [:class |
		class isActiveHostMenuItemClass ifTrue: [^ class]].

	"no responding subclass; use HostSystemMenusMenuItem"
	^ HostSystemMenusMenuItem

! !

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'JMM 10/18/2004 08:58'!
defaultMenuItem
	^ self activeMenuItemClass basicNew initialize.
! !

!HostSystemMenusMenuItem class methodsFor: 'handlers' stamp: 'John M McIntosh 12/25/2009 10:55'!
fakeKeyboardEventBlockMacRoman: anAsciiValue unicode: aUnicodeValue macKeyCode: aKeyCodeValue
	^[:evt | HostSystemMenusMenuItem processFakeKeyboardEvent: evt macRoman: anAsciiValue unicode: aUnicodeValue macKeyCode: aKeyCodeValue]! !

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'JMM 9/22/2004 15:21'!
menuString: aString 
	^self text: aString handler: self nullBlock! !

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'JMM 10/18/2004 14:52'!
menuString: aString  handler: aHandler
	^self text: aString handler: aHandler! !

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'John M McIntosh 12/25/2009 10:55'!
menuString: aString keyboardKey: aKey macKeyCode: aKeyCodeValue
	^self text: aString cmd: aKey asUppercase handler: 
		(self fakeKeyboardEventBlockMacRoman: aKey unicode: aKey macKeyCode: aKeyCodeValue )! !

!HostSystemMenusMenuItem class methodsFor: 'handlers' stamp: 'JMM 8/30/2004 16:52'!
nullBlock
	^[:evt | ]! !

!HostSystemMenusMenuItem class methodsFor: 'handlers' stamp: 'John M McIntosh 1/25/2010 10:16'!
processFakeKeyboardEvent: evt macRoman: aMacRomanValue unicode: aUnicodeValue macKeyCode: aKeyCodeValue
	|event |
	
		event := Array new: 8.
		event at: 1 put: 2 "EventTypeKeyboard";
		  at: 2 put: (evt at: 2); 
		  at: 3 put: aKeyCodeValue asInteger;  
		  at: 4 put: 1; "key down"
		  at: 5 put: 8; "modifier keys  (CmmandKeyBit)"
		  at: 8 put: (evt at: 8).
		Sensor handleEvent: event.

		event := Array new: 8.
		event at: 1 put: 2 "EventTypeKeyboard";
		  at: 2 put: (evt at: 2)+1; 
		  at: 3 put: aMacRomanValue asInteger;
		  at: 4 put: 0; "key char"
		  at: 5 put: 8; "modifier keys  (CmmandKeyBit)"
		  at: 6 put: aUnicodeValue asInteger; "virtual key code"
		  at: 8 put: (evt at: 8).
		Sensor handleEvent: event.

		event := Array new: 8.
		event at: 1 put: 2 "EventTypeKeyboard";
		  at: 2 put: (evt at: 2)+2; 
		  at: 3 put: aKeyCodeValue asInteger;
		  at: 4 put: 2; "key press/release"
		  at: 5 put: 8; "modifier keys  (CmmandKeyBit)"
		  at: 8 put: (evt at: 8).
		Sensor handleEvent: event! !

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'John M McIntosh 10/31/2008 19:28'!
subMenu: aMenuId menuString: aString 
	| item |
	
	item := self text: aString handler: self nullBlock.
	item mark: aMenuId.
	item cmd: 16r1B asCharacter.
	^item.! !

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'JMM 8/30/2004 16:56'!
text: aTextItem cmd: aCmd handler: aHandlerBlock
	| resolvedClassInstance |
	
	resolvedClassInstance := self defaultMenuItem.
	resolvedClassInstance text: aTextItem.
	resolvedClassInstance cmd: aCmd.
	resolvedClassInstance handler: aHandlerBlock.
	^resolvedClassInstance! !

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'JMM 9/18/2006 14:51'!
text: aTextItem cmd: aCmd shift: state handler: aHandlerBlock
	| resolvedClassInstance |
	
	resolvedClassInstance := self defaultMenuItem.
	resolvedClassInstance text: aTextItem.
	resolvedClassInstance cmd: aCmd.
	resolvedClassInstance shift: state.
	resolvedClassInstance handler: aHandlerBlock.
	^resolvedClassInstance! !

!HostSystemMenusMenuItem class methodsFor: 'instance creation' stamp: 'JMM 8/30/2004 16:56'!
text: aTextItem handler: aHandlerBlock
	| resolvedClassInstance |
	
	resolvedClassInstance := self defaultMenuItem.
	resolvedClassInstance text: aTextItem.
	resolvedClassInstance handler: aHandlerBlock.
	^resolvedClassInstance! !

!HostSystemMenusMenuItem methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:39'!
appleMark
	^nil! !

!HostSystemMenusMenuItem methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:39'!
checkMark
^nil! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
cmd
	"Answer the value of cmd"

	^ cmd! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
cmd: anObject
	"Set the value of cmd"

	cmd := anObject! !

!HostSystemMenusMenuItem methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:40'!
commandMark
^nil! !

!HostSystemMenusMenuItem methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:40'!
diamondMark
^nil! !

!HostSystemMenusMenuItem methodsFor: 'attributes' stamp: 'JMM 8/25/2004 10:30'!
disable
	disabled := true.! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
disabled
	"Answer the value of disabled"

	^ disabled! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
disabled: anObject
	"Set the value of disabled"

	disabled := anObject! !

!HostSystemMenusMenuItem methodsFor: 'attributes' stamp: 'JMM 8/25/2004 10:30'!
enable
	disabled := false.! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/30/2004 16:53'!
handler
	^handler! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/30/2004 16:54'!
handler: aHandlerBlock
	handler := aHandlerBlock! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
icon
	"Answer the value of icon"

	^ icon! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
icon: anObject
	"Set the value of icon"

	icon := anObject! !

!HostSystemMenusMenuItem methodsFor: 'initialize-release' stamp: 'alain.plantec 5/28/2009 09:57'!
initialize
	super initialize.
	self enable.
	self mark: self noMark.
	self style: Set new.
	! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
mark
	"Answer the value of mark"

	^ mark! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
mark: anObject
	"Set the value of mark"

	mark := anObject! !

!HostSystemMenusMenuItem methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:37'!
noMark
	^nil! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 9/18/2006 14:49'!
shift
	^shift == true! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 9/18/2006 14:49'!
shift: aBoolean
	shift := aBoolean! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
style
	"Answer the value of style"

	^ style! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:21'!
style: anObject
	"Set the value of style"

	style := anObject! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 13:08'!
styleAdd: aStyle

	style add: aStyle! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 13:08'!
styleRemove: aStyle

	style remove: aStyle ifAbsent: []! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:23'!
text
	"Answer the value of text"

	^ text! !

!HostSystemMenusMenuItem methodsFor: 'accessing' stamp: 'JMM 8/25/2004 10:23'!
text: anObject
	"Set the value of text"

	text := anObject! !

HostSystemMenusMenuItem subclass: #HostSystemMenusMenuItemMac
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HostMenus-Mac'!

!HostSystemMenusMenuItemMac commentStamp: 'JMM 10/22/2004 10:20' prior: 0!
mac specific information, contains the magic constants for the mark characters. !

!HostSystemMenusMenuItemMac class methodsFor: 'instance creation' stamp: 'simon.denier 6/11/2010 17:42'!
isActiveHostMenuItemClass
	^ OSPlatform isMacOS! !

!HostSystemMenusMenuItemMac methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:38'!
appleMark
	^20! !

!HostSystemMenusMenuItemMac methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:38'!
checkMark
	^18! !

!HostSystemMenusMenuItemMac methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:38'!
commandMark
	^17! !

!HostSystemMenusMenuItemMac methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:38'!
diamondMark
	^19! !

!HostSystemMenusMenuItemMac methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:41'!
hierMenu
	^-1! !

!HostSystemMenusMenuItemMac methodsFor: 'constants' stamp: 'JMM 8/25/2004 10:36'!
noMark
	^0! !

Object subclass: #HostSystemMenusProxy
	instanceVariableNames: 'application'
	classVariableNames: 'Registry'
	poolDictionaries: ''
	category: 'HostMenus-Mac'!

!HostSystemMenusProxy commentStamp: 'JMM 10/22/2004 10:24' prior: 0!
Proxy for the host api menu structure. 
All calls are managed by subclasses which support the menu API.
What is implemented is the finalization logic to ensure GCed menus are disposed of if the user forgets to dispose of the menu before he 
forgets about the instance of this class. 

!

HostSystemMenusProxy subclass: #HostSystemMenusMacOSX
	instanceVariableNames: 'menuBar menus'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HostMenus-Mac'!

!HostSystemMenusMacOSX commentStamp: 'JMM 10/15/2004 13:07' prior: 0!
Interface to the OS-9 classic menu bar macintosh plugin. 

Structure:
 isVMMenuBar	Boolean -- true if this menu bar was built by the VM
 menuBar		MenubarHandle -- The  magic number identifying the menubar
 menus			Dictionary -- Holds onto the definitions for each menu item in the menubar

Any further useful comments about the general approach of this implementation.
isVMMenuBar menuBar menus windowIndex !

!HostSystemMenusMacOSX class methodsFor: 'instance creation' stamp: 'StephaneDucasse 8/3/2010 22:54'!
isActiveHostMenuProxyClass
	"Am I active?"
	^ OSPlatform isMacOSX ! !

!HostSystemMenusMacOSX class methodsFor: 'instance creation' stamp: 'JMM 10/1/2004 15:15'!
new
	^self basicNew initialize! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'LaurentLaffont 6/22/2010 13:24'!
addHelpMenu
	| menu items |
	menu := self newMenu: 7 menuTitle: 'Help'.
	items := self buildSubMenusFor: (World worldMenuAt: #Help) items first subMenu.
	self appendMenu: menu menuItems: items.
	self insertMenu: menu beforeID: 0! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'LaurentLaffont 6/22/2010 13:23'!
addSystemMenu
	| menu items |
	menu := self newMenu: 6 menuTitle: 'System'.
	items := self buildSubMenusFor: (World worldMenuAt: #System) items first subMenu.
	self appendMenu: menu menuItems: items.
	self insertMenu: menu beforeID: 0! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'AdrianLienhard 6/5/2010 12:20'!
addToolsMenu
	| menu items |
	menu := self newMenu: 4 menuTitle: 'Tools'.
	items := self buildSubMenusFor: self openMenu.
	items removeLast.
	self appendMenu: menu menuItems: items.
	self insertMenu: menu beforeID: 4.! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'AdrianLienhard 6/5/2010 12:40'!
addWindowsMenu
	
	| menu items |
	
	menu := self newMenu: 5 menuTitle: 'Windows'.
	items := self buildSubMenusFor: (World worldMenuAt: #Windows) items first subMenu..
	self appendMenu: menu menuItems: items.
	self insertMenu: menu beforeID: 0! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'AdrianLienhard 6/5/2010 12:51'!
alterAppMenu 
	| appMenu items menu menuRef |	

	menuRef := self findApplicationMenuViaHideMenuItem.
	self rebuildApplicationMenuHandlers: menuRef.
	self disableApplicationHide: menuRef.
	self enableApplicationQuit: menuRef.

	appMenu := self getMenuHandle: 1.
	items := self buildSubMenusFor: (World worldMenuAt: #System) items first subMenu.
	"items at: 3 put: (HostSystemMenusMenuItem subMenu: 201 menuString: 'Preferences...')."
	
	items add: (HostSystemMenusMenuItem menuString: '-');
		add: (HostSystemMenusMenuItem menuString: 'Save' 
				handler: [:evt | Smalltalk snapshot: true andQuit: false ]);
		add: (HostSystemMenusMenuItem menuString: 'Save As...' 
				handler: [:evt | Smalltalk saveAs]);
		add: (HostSystemMenusMenuItem menuString: 'Save and Quit' 
				handler: [:evt | Smalltalk snapshot: true andQuit: true]).
	self appendMenu: appMenu menuItems: items! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'John M McIntosh 12/25/2009 10:46'!
alterEditMenu
	| editMenuID editMenu |
	editMenuID := 3.
	editMenu := OrderedCollection 
		with: (HostSystemMenusMenuItem menuString: 'Undo' keyboardKey: $z macKeyCode: 6)
		with: (HostSystemMenusMenuItem menuString: '_')
		with: (HostSystemMenusMenuItem menuString: 'Cut' keyboardKey: $x macKeyCode: 7)
		with: (HostSystemMenusMenuItem menuString: 'Copy' keyboardKey: $c macKeyCode: 8)
		with: (HostSystemMenusMenuItem menuString: 'Paste' keyboardKey: $v macKeyCode: 9)
		with: (HostSystemMenusMenuItem menuString: 'Clear').
	1 to: editMenu size do: 
		[:i | self setHandlerForMenu: editMenuID item: i  handler: (editMenu at: i)].
! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'MichaelRueger 12/25/2009 15:11'!
alterFileMenu 
	| fileMenu |	

	fileMenu := self getMenuHandle: 2.
	self deleteMenu: fileMenu.! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'LaurentLaffont 6/22/2010 13:24'!
alterMenus
	| editMenu fileMenuID editMenuID fileMenu menuRef |

	self alterEditMenu.

	"self appendStandardWindowMenu: 0."
	self alterFileMenu.
	self alterAppMenu.
	self
		addToolsMenu;
		addWindowsMenu;
		addSystemMenu;
		addHelpMenu.! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'HenrikSperreJohansen 1/21/2011 14:22'!
appearanceMenu
	"Build the appearance menu for the world."
	| items |
	items :={
		{'System fonts...' . {self . #standardFontDo} . 'Choose the standard fonts to use for code, lists, menus, window titles, etc.'}.
		nil.
		{#toggleScreenString . {Display . #toggleFullScreen}.}.
		{#soundEnablingString . {SoundService . #toggleSoundEnabling}. 'turning sound off will completely disable use of sound.'}.
		{'Set display depth...' . {self. #setDisplayDepth} . 'choose how many bits per pixel.'}.
		{'Set desktop color...' . {self. #changeBackgroundColor} . 'choose a uniform color to use as desktop background.'}.
		{'Set gradient color...' . {self. #setGradientColor} . 'choose second color to use as gradient for desktop background.'}.
		{'Set author full name...' . {Author . #requestFullName }. 'supply full name to be used to identify the author of code and other content.'}.
	}.
	^self fillIn: (self menu: 'Preferences') from: items.! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'John M McIntosh 10/31/2008 19:09'!
appendMenu: aMenuHandle menuItems: aCollection
	| str255  |
	
	aCollection do: [:e | |subCollection|
		subCollection := OrderedCollection with: e.
		str255 := self buildDataStringForAppendOrInsert: subCollection.
		self resolveAppendOfMenuItems: subCollection forMenuHandle: aMenuHandle.
		self primAppendMenu: aMenuHandle data: str255].
 ! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 11:08'!
appendMenuItemText: menuHandleOop data: menuItemText
	| str255 |
	
	str255 := self convertToStr255: menuItemText.
 	^self primAppendMenuItemText: menuHandleOop data: str255! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:06'!
appendStandardWindowMenu: inOptions
	| commandID menuItemIndex windowMenu xID x |
	
	"See http://developer.apple.com/documentation/Carbon/Reference/Carbon:=Event:=Manager:=Ref/CarbonEventsRef/enum:=group:=5.html"
	"Install standard window menu, 
	Disable minimize window menu key,
	Disable hide application cmd key
	Note that after 10.2.x to alter the standard window menu you must do a getIndMenuItemWithCommandID:item: to have the menu built. Also it appears we must do a getMenuID/getMenuHandle to grab the correct handle, versus the template"

	"Build the standard Window menu and disable minimize cmd key"
	windowMenu := self createStandardWindowMenu: inOptions. 
	self insertMenu: windowMenu beforeID: 0.
	xID := self getMenuID: windowMenu.
	x := self getMenuHandle: xID. 

	commandID := MacOSType buildOSTypeFromCharString: 'mini'.
	menuItemIndex := self getIndMenuItemWithCommandID: x item: commandID.
	self setItemCmd: x item: 1 cmdChar: 0.
! !

!HostSystemMenusMacOSX methodsFor: 'translation' stamp: 'PeterHugossonMiller 9/3/2009 10:00'!
buildDataStringForAppendOrInsert: aCollection
	| first str icon mark style cmd |

	first := true.
	str := (String new: 80) writeStream.
	aCollection do: [:m |
		first ifFalse: [str nextPutAll: ';'].
		first ifTrue: [first := false].
		str nextPutAll: m text.
		(icon := m icon) ifNotNil: [str nextPutAll: '^';nextPutAll: icon printString].
		(mark := m mark) ifNotNil: [str nextPutAll: '!!';nextPut: mark asCharacter].
		(style := m style) ifNotNil: [str nextPutAll: (self resolveStyle: style)].
		(cmd := m cmd) ifNotNil: [str nextPutAll: '/';nextPut: cmd].
		m disabled ifTrue: [str nextPutAll: '('].
		].
	^self convertToStr255: str contents.
	! !

!HostSystemMenusMacOSX methodsFor: 'translation' stamp: 'JMM 8/25/2004 16:19'!
buildModifers: integer
	| modifiers |
	integer isZero ifTrue: [^Set with: #command].
	modifiers := Set new.
	(integer bitAnd: 1) > 0 ifTrue: [modifiers add: #shift].
	(integer bitAnd: 2) > 0 ifTrue: [modifiers add: #option].
	(integer bitAnd: 4) > 0 ifTrue: [modifiers add: #control].
	(integer bitAnd: 8) > 0 ifTrue: [modifiers add: #nocommand].
	^modifiers! !

!HostSystemMenusMacOSX methodsFor: 'translation' stamp: 'JMM 8/25/2004 15:45'!
buildStyle: integer
	| styles |
	styles := Set new.
	(integer bitAnd: 1) > 0 ifTrue: [styles add: #bold].
	(integer bitAnd: 2) > 0 ifTrue: [styles add: #italic].
	(integer bitAnd: 4) > 0 ifTrue: [styles add: #underline].
	(integer bitAnd: 8) > 0 ifTrue: [styles add: #outline].
	(integer bitAnd: 16) > 0 ifTrue: [styles add: #shadow].
	^styles! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:26'!
buildSubMenusFor: menu
	| items |
	
	items := OrderedCollection new. 
	menu items do: [:e |
		items add: (HostSystemMenusMenuItem menuString: (self modifySqueakMenu: e contents) 
				handler: [:evt | 
					e doButtonAction])].	
	^items	
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 12:29'!
checkMenuItem: aMenuHandle item: anInteger checked: aBoolean
	self primCheckMenuItem: aMenuHandle item: anInteger checked: aBoolean

! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:40'!
clearMenuBar: aWindowIndex
	self primClearMenuBar! !

!HostSystemMenusMacOSX methodsFor: 'translation' stamp: 'StephaneDucasse 2/3/2010 22:14'!
convertToStr255: aString
	| str255 size |
	str255 := ByteArray new: 256.
	size := aString size.
	size > 255 ifTrue: [self error: 'String is too long'].
	str255 byteAt: 1 put: size.
	str255 replaceFrom: 2 to: size + 1 with: aString startingAt: 1.
	^str255
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:09'!
countMenuItems: aMenuHandle
	^self primCountMenuItems: aMenuHandle! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:40'!
createMenuBar: aWindowIndex
	! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:26'!
createStandardWindowMenu: inOptions
	^self primCreateStandardWindowMenu: inOptions! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/18/2004 14:37'!
deleteMenu: aMenuHandle
		| menuID |
	menuID := self getMenuID: aMenuHandle.
	self menus removeKey: menuID ifAbsent: [nil].
	self primDeleteMenu: menuID.
	self primDisposeMenu: aMenuHandle.
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:11'!
deleteMenuItem: aMenuHandle item: aNumber
	self primDeleteMenuItem: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'initialize-release' stamp: 'MichaelRueger 12/25/2009 14:57'!
destroyEveryThing
	"No other than the VM menu bar supported right now.
	do nothing"
	"BTW, this never worked as isVMMenuBar: threw an error)"
	"self disposeMenuBar: 1.
	menuBar := nil"! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:25'!
disableApplicationHide: aMenuRef 
		"Disable the hide cmd key"
	| commandID menuItemIndex |

	commandID := MacOSType buildOSTypeFromCharString: 'hide'.
	menuItemIndex := self getIndMenuItemWithCommandID: aMenuRef item: commandID.
	self setItemCmd: aMenuRef item: menuItemIndex cmdChar: 0.
! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:25'!
disableHideMenuCmd
	| commandID menuRef menuItemIndex |

	"Comand ID for hide"

	commandID := MacOSType buildOSTypeFromCharString: 'hide'.
	menuRef := self getIndMenuWithCommandID: 0 item: commandID.
	menuItemIndex := self getIndMenuItemWithCommandID: 0 item: commandID.
	self setItemCmd: menuRef item: menuItemIndex cmdChar: 0.

! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:12'!
disableMenuItem: aMenuHandle item: aNumber
	self primDisableMenuItem: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'MichaelRueger 12/25/2009 14:58'!
disposeMenuBar: aWindowIndex
	self error: 'Should not be reached right now'
	"(self isVMMenuBar: aWindowIndex) ifTrue: [^self].
	menuBar ifNotNil: [self primDisposeMenuBar: menuBar].
	menuBar := nil"! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/1/2004 13:04'!
drawMenuBar
	self primDrawMenuBar! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 13:08'!
drawMenuBar: aWindowIndex
	self primDrawMenuBar! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:25'!
enableApplicationQuit: aMenuRef 
	| commandID |

	commandID := MacOSType buildOSTypeFromCharString: 'quit'.
	self enableMenuCommand: aMenuRef command: commandID.
	
	! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:27'!
enableMenuCommand: menuHandleOop command: aCommandID
	self primEnableMenuCommand: menuHandleOop command: aCommandID! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 19:10'!
enableMenuItem: aMenuHandle item: aNumber
	self  primEnableMenuItem: aMenuHandle item: aNumber.! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'AlainPlantec 2/16/2010 23:58'!
fillIn: aMenu from: dataForMenu
	"A menu constructor utility by RAA.  dataForMenu is a list of items which mean:
			nil							Indicates to add a line

			first element is symbol		Add updating item with the symbol as the wording selector
			second element is a list		second element has the receiver and selector

			first element is a string		Add menu item with the string as its wording
			second element is a list		second element has the receiver and selector

			a third element exists		Use it as the balloon text
			a fourth element exists		Use it as the enablement selector (updating case only)"
	

	dataForMenu do: [ :itemData | | item |
		itemData ifNil: [aMenu addLine] ifNotNil:
			[item := (itemData first isKindOf: Symbol)
				ifTrue: 
					[aMenu 
						addUpdating: itemData first
						target: self 
						selector: #doMenuItem:with: 
						argumentList: {itemData second}]
				 ifFalse:
					[aMenu 
						add: (itemData first translated) capitalized
						target: self 
						selector: #doMenuItem:with: 
						argumentList: {itemData second}].
			itemData size >= 3 ifTrue:
				[aMenu balloonTextForLastItem: itemData third translated.
			itemData size >= 4 ifTrue:
				[item enablementSelector: itemData fourth]]]].

	^ aMenu! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:25'!
findApplicationMenuViaHideMenuItem
	| commandID menuRef |

	commandID := MacOSType buildOSTypeFromCharString: 'hide'.
	menuRef := self getIndMenuWithCommandID: 0 item: commandID.
	^menuRef
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/18/2004 15:02'!
getHandlerForMenu: aMenuID item: anItem
	| menu menuItemHandler |
	
	menu := self menus at: aMenuID ifAbsentPut: [Dictionary new].
	menuItemHandler := menu at: anItem ifAbsentPut: [HostSystemMenusMenuItem menuString: ''].
	^menuItemHandler! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:27'!
getIndMenuItemWithCommandID: aMenuHandle item: aCommandID
	^self primGetIndMenuItemWithCommandID: aMenuHandle commandID: aCommandID! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:27'!
getIndMenuWithCommandID: aMenuHandle item: aCommandID
	^self primGetIndMenuWithCommandID: aMenuHandle commandID: aCommandID! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:13'!
getItemCmd: aMenuHandle item: aNumber
	^(self primGetItemCmd: aMenuHandle item: aNumber) asCharacter! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:13'!
getItemIcon: aMenuHandle item: aNumber
	^self primGetItemIcon: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:14'!
getItemMark: aMenuHandle item: aNumber
	^(self primGetItemMark: aMenuHandle item: aNumber) asCharacter! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 11:12'!
getItemStyle: aMenuHandle item: aNumber
	^self buildStyle: (self primGetItemStyle: aMenuHandle item: aNumber)
	! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:14'!
getMenuHandle: aMenuID
	^self primGetMenuHandle: aMenuID! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:14'!
getMenuID: aMenuHandle
	^self primGetMenuID: aMenuHandle! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/23/2004 12:32'!
getMenuItemCommandID: aMenuHandle item: aNumber
	^self primGetMenuItemCommandID: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/23/2004 12:34'!
getMenuItemFontID: aMenuHandle item: aNumber
	^self primGetMenuItemFontID: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 15:52'!
getMenuItemHierarchicalID: menuHandleOop item: anInteger 
	^self primGetMenuItemHierarchicalID: menuHandleOop item: anInteger ! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/23/2004 12:39'!
getMenuItemKeyGlyph: aMenuHandle item: aNumber
	^self primGetMenuItemKeyGlyph: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/25/2004 16:20'!
getMenuItemModifiers: aMenuHandle item: aNumber
	^self buildModifers: (self primGetMenuItemModifiers: aMenuHandle item: aNumber)! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:14'!
getMenuItemText: aMenuHandle item: aNumber
	^self primGetMenuItemText: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/23/2004 12:59'!
getMenuItemTextEncoding: aMenuHandle item: aNumber
	^self primGetMenuItemTextEncoding: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:14'!
getMenuTitle: aMenuHandle
	^self primGetMenuTitle: aMenuHandle! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:41'!
hideMenuBar: aWindowIndex
	self primHideMenuBar! !

!HostSystemMenusMacOSX methodsFor: 'initialize-release' stamp: 'MichaelRueger 12/25/2009 15:17'!
initialize
	| menuHandle |
	super initialize.
	menus := Dictionary new.
	self alterMenus.
	self menuBar.
	menuHandle := self getMenuHandle: 3.
	self enableMenuItem: menuHandle item: 1.
	self enableMenuItem: menuHandle item: 3.
	self enableMenuItem: menuHandle item: 4.
	self enableMenuItem: menuHandle item: 5.
	self drawMenuBar.
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 12:38'!
insertFontResMenu: menuHandleOop afterItem: afterItemInteger scriptFilter:  scriptFilterInteger
	self primInsertFontResMenu: menuHandleOop afterItem: afterItemInteger scriptFilter:  scriptFilterInteger

! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:14'!
insertMenu: aMenuHandle beforeID: anId
	self primInsertMenu: aMenuHandle beforeID: anId! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 9/2/2004 22:04'!
insertMenuItem: menuHandleOop item: aItem afterItem: anInteger
	| str255 |
	str255 := self buildDataStringForAppendOrInsert: (OrderedCollection with: aItem).
	self resolveInsertOfMenuItem: aItem afterItem: anInteger forMenuHandle: menuHandleOop.
	self primInsertMenuItem: menuHandleOop itemString: str255 afterItem: anInteger.

! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 8/23/2004 14:11'!
invalMenuBar
	self primInvalMenuBar! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:42'!
isMenuBarVisible: aWindowIndex
	^self primIsMenuBarVisible! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:15'!
isMenuItemEnabled: aMenuHandle item: aNumber
	^self primIsMenuItemEnabled: aMenuHandle item: aNumber! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 12:32'!
menuBar
	menuBar ifNil: 
			[menuBar := self primGetMenuBar].
	^menuBar! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/1/2004 12:59'!
menus
	^menus! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MichaelRueger 12/25/2009 15:25'!
modifySqueakMenu: aString
	| results fixIndex middleCharacter |
	results := aString.
	results replaceAll: $; with: Character space.
	results replaceAll: $^ with: Character space.
	results replaceAll: $!! with: Character space.
	results replaceAll: $< with: Character space.
	results replaceAll: $/ with: Character space.
	fixIndex := results indexOf: $(.
	[fixIndex > 0]
		whileTrue: [
			[(results at: fixIndex + 2) = $)
				ifTrue: [middleCharacter := results at: fixIndex + 1.
						(middleCharacter = Character space or: [middleCharacter = $(])
							ifTrue: [results at: fixIndex put: Character space]
							ifFalse: [results at: fixIndex put: $/.].
						results at: fixIndex + 1 put: middleCharacter asUppercase.
						results at: fixIndex + 2 put: Character space]
				ifFalse: [results at: fixIndex put: Character space]]
					ifError: [results at: fixIndex put:  Character space].
			fixIndex := results indexOf: $(].
	^ results! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 11:09'!
newMenu: menuID menuTitle: menuTitle
	| str255 |
	
	str255 := self convertToStr255: menuTitle.
 	^self primNewMenu: menuID menuTitle: str255! !

!HostSystemMenusMacOSX methodsFor: 'building-menus' stamp: 'IgorStasenko 4/26/2011 16:56'!
openMenu
	"Build the open window menu for the world."

	| menu |
	menu := UIManager default
				 newMenuIn: self for: Smalltalk tools.
	menu addList: Smalltalk tools menuItems.
	^menu! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 11:20'!
primAppendMenu: menuHandleOop data: str255
	<primitive: 'primitiveAppendMenu' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 12:12'!
primAppendMenuItemText: menuHandleOop data: str255
	<primitive: 'primitiveAppendMenuItemText' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 14:21'!
primCheckMenuItem: aMenuHandle item: anInteger checked: aBoolean
	<primitive: 'primitiveCheckMenuItem' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/24/2004 17:59'!
primClearMenuBar
	<primitive: 'primitiveClearMenuBar' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 11:45'!
primCountMenuItems: aMenuHandle
	<primitive: 'primitiveCountMenuItems' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'MichaelRueger 12/25/2009 14:58'!
primCreateStandardWindowMenu: inOptions 
	<primitive: 'primitiveCreateStandardWindowMenu' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/24/2004 17:24'!
primDeleteMenu: aMenuID
	<primitive: 'primitiveDeleteMenu' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 14:30'!
primDeleteMenuItem: aMenuHandle item: anInteger
	<primitive: 'primitiveDeleteMenuItem' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'MichaelRueger 12/25/2009 14:58'!
primDisableMenuCommand: menuHandleOop command: aCommandID
	<primitive: 'primitiveDisableMenuCommand' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 14:31'!
primDisableMenuItem: aMenuHandle item: anInteger
	<primitive: 'primitiveDisableMenuItem' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/24/2004 17:26'!
primDisposeMenu: aMenuHandle
	<primitive: 'primitiveDisposeMenu' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 10:24'!
primDisposeMenuBar: aMenuBar
	<primitive: 'primitiveDisposeMenuBar' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 13:15'!
primDrawMenuBar
	<primitive: 'primitiveDrawMenuBar' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'MichaelRueger 12/25/2009 14:59'!
primEnableMenuCommand: menuHandleOop command: aCommandID
	<primitive: 'primitiveEnableMenuCommand' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 14:29'!
primEnableMenuItem: aMenuHandle item: anInteger
	<primitive: 'primitiveEnableMenuItem' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'MichaelRueger 12/25/2009 14:59'!
primGetIndMenuItemWithCommandID: aMenuHandle commandID: aCommandID
	<primitive: 'primitiveGetIndMenuItemWithCommandID' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 10/7/2004 12:18'!
primGetIndMenuWithCommandID: aMenuHandle commandID: aCommandID
	<primitive: 'primitiveGetIndMenuWithCommandID' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 13:51'!
primGetItemCmd: aMenuHandle item: anInteger
	<primitive: 'primitiveGetItemCmd' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 13:58'!
primGetItemIcon: aMenuHandle item: anInteger
	<primitive: 'primitiveGetItemIcon' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 14:02'!
primGetItemMark: aMenuHandle item: anInteger
	<primitive: 'primitiveGetItemMark' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 14:08'!
primGetItemStyle: aMenuHandle item: anInteger
	<primitive: 'primitiveGetItemStyle' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 09:22'!
primGetMenuBar
	<primitive: 'primitiveGetMenuBar' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 10:31'!
primGetMenuHandle: aMenuHandle
	<primitive: 'primitiveGetMenuHandle' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/24/2004 17:42'!
primGetMenuID: aMenuHandle
	<primitive: 'primitiveGetMenuID' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'MichaelRueger 12/25/2009 14:59'!
primGetMenuItemCommandID: aMenuHandle item: anInteger
	<primitive: 'primitiveGetMenuItemCommandID' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 13:17'!
primGetMenuItemFontID: menuHandleOop item: anInteger 
	<primitive: 'primitiveGetMenuItemFontID' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 15:52'!
primGetMenuItemHierarchicalID: menuHandleOop item: anInteger 
	<primitive: 'primitiveGetMenuItemHierarchicalID' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 12:39'!
primGetMenuItemKeyGlyph: aMenuHandle item: anInteger
	<primitive: 'primitiveGetMenuItemKeyGlyph' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 12:50'!
primGetMenuItemModifiers: aMenuHandle item: anInteger
	<primitive: 'primitiveGetMenuItemModifiers' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 12:16'!
primGetMenuItemText: aMenuHandle item: anInteger
	<primitive: 'primitiveGetMenuItemText' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 13:02'!
primGetMenuItemTextEncoding: aMenuHandle item: anInteger
	<primitive: 'primitiveGetMenuItemTextEncoding' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 12:04'!
primGetMenuTitle: aMenuHandle
	<primitive: 'primitiveGetMenuTitle' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 13:12'!
primHideMenuBar
	<primitive: 'primitiveHideMenuBar' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 16:16'!
primHiliteMenu: menuID 
	<primitive: 'primitiveHiliteMenu' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 12:38'!
primInsertFontResMenu: menuHandleOop afterItem: afterItemInteger scriptFilter:  scriptFilterInteger
	<primitive: 'primitiveInsertFontResMenu' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 15:25'!
primInsertMenu: aMenuHandle beforeID: anId
	<primitive: 'primitiveInsertMenu' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 14:39'!
primInsertMenuItem: aMenuHandle itemString: str255 afterItem: anInteger
	<primitive: 'primitiveInsertMenuItem' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 14:10'!
primInvalMenuBar
	<primitive: 'primitiveInvalMenuBar' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 13:24'!
primIsMenuBarVisible
	<primitive: 'primitiveIsMenuBarVisible' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 14:23'!
primIsMenuItemEnabled: aMenuHandle item: anInteger
	<primitive: 'primitiveIsMenuItemEnabled' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 15:08'!
primNewMenu: aMenuID menuTitle: menuTitle
	<primitive: 'primitiveNewMenu' module: 'MacMenubarPlugin'>
	self primitiveFailed
	! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 14:53'!
primSetItemCmd: menuHandleOop item: anInteger cmdChar: anIntegerCmdChar
	<primitive: 'primitiveSetItemCmd' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 14:59'!
primSetItemMark: menuHandleOop item: anInteger markChar: aMarkChar
	<primitive: 'primitiveSetItemMark' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 15:44'!
primSetItemStyle: menuHandleOop item: anInteger styleParameter: chStyleInteger
	<primitive: 'primitiveSetItemStyle' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 16:17'!
primSetMenuBar: menuHandleOop
	<primitive: 'primitiveSetMenuBar' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 16:05'!
primSetMenuItemCommandID: menuHandleOop item: anInteger menuCommand:  inCommandID
	<primitive: 'primitiveSetMenuItemCommandID' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 13:16'!
primSetMenuItemFontID: menuHandleOop item: anInteger fontID: aFontIDInteger  
	<primitive: 'primitiveSetMenuItemFontID' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 14:49'!
primSetMenuItemHierarchicalID: menuHandleOop item: anInteger hierID: aMenuID
	<primitive: 'primitiveSetMenuItemHierarchicalID' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 16:00'!
primSetMenuItemKeyGlyph: menuHandleOop item: anInteger glyph:  inGlyphInteger
	<primitive: 'primitiveSetMenuItemKeyGlyph' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/25/2004 16:13'!
primSetMenuItemModifiers: menuHandleOop item: anInteger inModifiers: aUInt8
	<primitive: 'primitiveSetMenuItemModifiers' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 10:58'!
primSetMenuItemText: menuHandleOop item: anInteger  itemString: str255
	<primitive: 'primitiveSetMenuItemText' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 12:49'!
primSetMenuItemTextEncoding: menuHandleOop item: anInteger inScriptID: aTextEncodingOop
	<primitive: 'primitiveSetMenuItemTextEncoding' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/26/2004 12:46'!
primSetMenuTitle: menuHandleOop  title: str255
	<primitive: 'primitiveSetMenuTitle' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'system primitives' stamp: 'JMM 8/23/2004 13:08'!
primShowMenuBar
	<primitive: 'primitiveShowMenuBar' module: 'MacMenubarPlugin'>
	self primitiveFailed! !

!HostSystemMenusMacOSX methodsFor: 'utility' stamp: 'MikeRoberts 8/2/2010 21:26'!
rebuildApplicationMenuHandlers: aMenuRef
	| maximumItems applicationMenuItemsTitles applicationMenuItems m applicationQuit |
	maximumItems := self countMenuItems: aMenuRef.
	applicationMenuItemsTitles := (1 to: maximumItems) collect: [:i | self getMenuItemText: aMenuRef item: i]. 	
	applicationMenuItems := applicationMenuItemsTitles collect: [:e | HostSystemMenusMenuItem menuString: e].
	"At this point only 1 item has quit in the text otherwise this would not be reliable."
	applicationQuit := applicationMenuItems detect: [:e | e text includesSubstring: 'Quit' caseSensitive: false] ifNone: [nil].
	applicationQuit
		ifNil: [Transcript cr; show: 'Warning: no Quit host menu found.'; cr]
		ifNotNil: [
			applicationQuit handler: [:evt | | result |
				result := self confirm: 'Save changes before quitting?'
								orCancel: [nil].
				result ifNotNil: [
					Smalltalk snapshot: result andQuit: true]]].
	m := Dictionary new.
	applicationMenuItems doWithIndex:[:e :i | m at: i put: e].
	self menus at: (self getMenuID: aMenuRef) put: m.

! !

!HostSystemMenusMacOSX methodsFor: 'handlers' stamp: 'JMM 10/18/2004 14:17'!
resolveAppendOfMenuItems: aCollection forMenuHandle: aMenuHandle
	| previousItems menuID |
	
	previousItems := self countMenuItems: aMenuHandle.
	menuID := self getMenuID:  aMenuHandle.
	1 to: aCollection size do: 
		[:i | self setHandlerForMenu: menuID item: i + previousItems handler: (aCollection at: i)]
	! !

!HostSystemMenusMacOSX methodsFor: 'handlers' stamp: 'JMM 10/18/2004 14:17'!
resolveInsertOfMenuItem: aMenuItem afterItem: anIndex forMenuHandle: aMenuHandle
	| menuID count workList item |
	
	menuID := self getMenuID:  aMenuHandle.
	count := (self menus at: menuID) size.
	workList := OrderedCollection new. 
	1 to: count do: [:i |
		item := self getHandlerForMenu: menuID item: i.
		i = (anIndex+1) ifTrue: [workList add: aMenuItem].
		workList add: item].
	count = anIndex ifTrue: [workList add: aMenuItem].
	1 to: count + 1 do: [:i |
		self setHandlerForMenu: menuID item: i handler: (workList at: i)]
	! !

!HostSystemMenusMacOSX methodsFor: 'translation' stamp: 'JMM 8/25/2004 16:35'!
resolveModifiersInteger: modifers
	
	| integer |
	integer := 0.
	#(#shift 1 #option 2 #control 4 #nocommand 8) 
		pairsDo: [:style :bitOffset |
			(modifers includes: style) ifTrue: [integer := integer bitOr: bitOffset]].
	^integer
! !

!HostSystemMenusMacOSX methodsFor: 'translation' stamp: 'JMM 8/25/2004 11:41'!
resolveStyle: aStyle
	| string |
	
	string := String new.
	aStyle do: [:s |
			string := string,'<'.
			s = #bold ifTrue: [string := string,'B'].
			s = #italic ifTrue: [string := string,'I'].
			s = #underline ifTrue: [string := string,'U'].
			s = #outline ifTrue: [string := string,'O'].
			s = #shadow ifTrue: [string := string,'S']].
	^string.
! !

!HostSystemMenusMacOSX methodsFor: 'translation' stamp: 'JMM 8/25/2004 16:01'!
resolveStyleInteger: aStyle
	
	| integer |
	integer := 0.
	#(#bold 1 #italic 2 #underline 4 #outline 8 #shadow 16) 
		pairsDo: [:style :bitOffset |
			(aStyle includes: style) ifTrue: [integer := integer bitOr: bitOffset]].
	^integer
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:06'!
setHandlerForMenu: aMenuID item: anItem handler: aHandler
	| menu |
	
	menu := self menus at: aMenuID ifAbsentPut: [Dictionary new].
	menu at: anItem put: aHandler


! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:16'!
setItemCmd: menuHandleOop item: anInteger cmdChar: anIntegerCmdChar
	self primSetItemCmd: menuHandleOop item: anInteger cmdChar: anIntegerCmdChar asCharacter asInteger
	
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:16'!
setItemMark: menuHandleOop item: anInteger markChar: aMarkChar
	self primSetItemMark: menuHandleOop item: anInteger markChar: aMarkChar asCharacter asInteger
	
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:16'!
setItemStyle: menuHandleOop item: anInteger style: aStyle
	| styleInteger |
	
	styleInteger := self resolveStyleInteger: aStyle.
	self primSetItemStyle: menuHandleOop item: anInteger styleParameter: styleInteger
	
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:16'!
setMenuItemCommandID: menuHandleOop item: anInteger menuCommand:  inCommandID
	self primSetMenuItemCommandID: menuHandleOop item: anInteger menuCommand:  inCommandID  asInteger
	
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 13:17'!
setMenuItemFontID: menuHandleOop item: anInteger fontID: aFontIDInteger  
	self primSetMenuItemFontID: menuHandleOop item: anInteger fontID: aFontIDInteger  
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 19:00'!
setMenuItemHierarchicalID: menuHandleOop item: anInteger hierID: aMenuID
	self primSetMenuItemHierarchicalID: menuHandleOop item: anInteger hierID: aMenuID! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 16:00'!
setMenuItemKeyGlyph: menuHandleOop item: anInteger glyph:  inGlyphInteger
	self primSetMenuItemKeyGlyph: menuHandleOop item: anInteger glyph:  inGlyphInteger! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/25/2004 16:55'!
setMenuItemModifiers: menuHandleOop item: anInteger inModifiers: modifers
	| modifiersInteger |
	modifiersInteger := self resolveModifiersInteger: modifers.
	self primSetMenuItemModifiers: menuHandleOop item: anInteger inModifiers:  modifiersInteger 
	
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 11:15'!
setMenuItemText: menuHandleOop item: anInteger itemString: aMenuItemText
	| str255 |
	
	str255 := self convertToStr255: aMenuItemText.
	self primSetMenuItemText: menuHandleOop item: anInteger itemString: str255
	
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 8/26/2004 12:50'!
setMenuItemTextEncoding: menuHandleOop item: anInteger inScriptID: aTextEncodingOop
	self primSetMenuItemTextEncoding: menuHandleOop item: anInteger inScriptID: aTextEncodingOop
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menus' stamp: 'JMM 10/1/2004 13:17'!
setMenuTitle: menuHandleOop  title: aMenuText
	| str255 |
	
	str255 := self convertToStr255: aMenuText.
	self primSetMenuTitle: menuHandleOop  title: str255
	
! !

!HostSystemMenusMacOSX methodsFor: 'accessing-menuBar' stamp: 'JMM 10/15/2004 12:42'!
showMenuBar: aWindowIndex
	self primShowMenuBar! !

!HostSystemMenusProxy class methodsFor: 'instance creation' stamp: 'JMM 10/12/2004 11:13'!
isActiveHostMenuProxyClass
	^false.! !

!HostSystemMenusProxy class methodsFor: 'instance creation' stamp: 'JMM 10/12/2004 12:35'!
new
	^self basicNew initialize! !

!HostSystemMenusProxy class methodsFor: 'registery' stamp: 'HenrikSperreJohansen 5/20/2010 22:36'!
register: anObject

	^self registry add: anObject! !

!HostSystemMenusProxy class methodsFor: 'registery' stamp: 'HenrikSperreJohansen 5/20/2010 22:36'!
registry
	^Registry ifNil: [Registry := WeakRegistry new]
	! !

!HostSystemMenusProxy class methodsFor: 'registery' stamp: 'HenrikSperreJohansen 5/20/2010 22:37'!
unregister: anObject
	
	^self registry remove: anObject ifAbsent:[]! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:16'!
appendMenu: aMenuHandle menuItems: aCollection! !

!HostSystemMenusProxy methodsFor: 'accessing' stamp: 'JMM 5/15/2006 21:42'!
application
	^application! !

!HostSystemMenusProxy methodsFor: 'accessing' stamp: 'JMM 5/15/2006 21:42'!
application: aValue
	application := aValue! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:16'!
checkMenuItem: aMenuHandle item: anInteger checked: aBoolean! !

!HostSystemMenusProxy methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 12:09'!
clearMenuBar! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:16'!
countMenuItems: aMenuHandle! !

!HostSystemMenusProxy methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 12:09'!
createMenuBar! !

!HostSystemMenusProxy methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 14:32'!
defaultMenuBarForWindowIndex: aWindowIndex
	^self! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:16'!
deleteMenu: aMenuHandle! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:16'!
deleteMenuItem: aMenuHandle item: aNumber! !

!HostSystemMenusProxy methodsFor: 'initialize-release' stamp: 'JMM 10/12/2004 14:13'!
destroyEveryThing
	self unregister! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:16'!
disableMenuItem: aMenuHandle item: aNumb! !

!HostSystemMenusProxy methodsFor: 'initialize-release' stamp: 'JMM 10/12/2004 12:21'!
disposeMenuBar! !

!HostSystemMenusProxy methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 12:11'!
drawMenuBar! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:16'!
enableMenuItem: aMenuHandle item: aNumber! !

!HostSystemMenusProxy methodsFor: 'finalization' stamp: 'HenrikSperreJohansen 6/28/2010 12:21'!
finalize
	[self destroyEveryThing] ifError: [].
	! !

!HostSystemMenusProxy methodsFor: 'accessing' stamp: 'JMM 10/12/2004 12:45'!
getHandlerForMenu: aMenuID item: anItem
	^[:nothing | ]! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:16'!
getItemCmd: aMenuHandle item: aNumber! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:17'!
getItemIcon: aMenuHandle item: aNumber! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:17'!
getItemMark: aMenuHandle item: aNumber! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:17'!
getItemStyle: aMenuHandle item: aNumber! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:17'!
getMenuHandle: aMenuID! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:17'!
getMenuID: aMenuHandle! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:17'!
getMenuItemText: aMenuHandle item: aNumber! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:17'!
getMenuTitle: aMenuHandle! !

!HostSystemMenusProxy methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 12:11'!
hideMenuBar! !

!HostSystemMenusProxy methodsFor: 'initialize-release' stamp: 'alain.plantec 5/28/2009 09:57'!
initialize
	super initialize.
	self register! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:17'!
insertMenu: aMenuHandle beforeID: anId! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:18'!
insertMenuItem: menuHandleOop item: anItem afterItem: anInteger
! !

!HostSystemMenusProxy methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 12:12'!
isMenuBarVisible
	^true! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:18'!
isMenuItemEnabled: aMenuHandle item: aNumber
! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:18'!
newMenu: xmenuID menuTitle: menuTitle! !

!HostSystemMenusProxy methodsFor: 'finalization' stamp: 'JMM 10/12/2004 11:19'!
register
	^self class register: self! !

!HostSystemMenusProxy methodsFor: 'initialize-release' stamp: 'JMM 5/15/2006 23:24'!
reviseHostMenus! !

!HostSystemMenusProxy methodsFor: 'accessing' stamp: 'JMM 10/12/2004 12:14'!
setHandlerForMenu: aMenuID item: anItem handler: aHandler
! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:18'!
setItemCmd: menuHandleOop item: anInteger cmdChar: anIntegerCmdChar! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:18'!
setItemMark: menuHandleOop item: anInteger markChar: aMarkChar! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:18'!
setItemStyle: menuHandleOop item: anInteger style: aStyle! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:18'!
setMenuItemHierarchicalID: menuHandleOop item: anInteger hierID: aMenuID! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:19'!
setMenuItemModifiers: menuHandleOop item: anInteger inModifiers: aUInt8! !

!HostSystemMenusProxy methodsFor: 'accessing-menus' stamp: 'JMM 10/12/2004 12:19'!
setMenuTitle: menuHandleOop  title: aMenuText! !

!HostSystemMenusProxy methodsFor: 'accessing-menuBar' stamp: 'JMM 10/12/2004 12:12'!
showMenuBar! !

!HostSystemMenusProxy methodsFor: 'finalization' stamp: 'JMM 10/12/2004 11:20'!
unregister
	^self class unregister: self! !

HostSystemMenusProxy subclass: #HostSystemMenusWindows
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HostMenus-Mac'!

!HostSystemMenusWindows class methodsFor: 'instance creation' stamp: 'simon.denier 6/11/2010 17:43'!
isActiveHostMenuProxyClass
	"Am I active?"
	^OSPlatform  isWin32! !

!HostSystemMenusWindows methodsFor: 'as yet unclassified' stamp: 'be 8/13/2006 15:54'!
toggleReaderMode: aValue! !

HostSystemMenusProxy subclass: #MacOSType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HostMenus-Mac'!

!MacOSType class methodsFor: 'utility' stamp: 'JMM 1/15/2007 12:28'!
buildOSTypeFromCharString: folderTypeData 
	"preserve platform endianness"

	^folderTypeData asByteArray unsignedLongAt: 1 bigEndian: true! !
HostSystemMenus initialize!
